@@ -1,9 +1,7 @@
 # et:ts=4
 # portdistcheck.tcl
 #
-# $Id$
-#
-# Copyright (c) 2007-2011 The MacPorts Project
+# Copyright (c) 2007-2011, 2014, 2016 The MacPorts Project
 # Copyright (c) 2005-2006 Paul Guyot <pguyot@kallisys.net>,
 # All rights reserved.
 #
@@ -60,57 +58,59 @@ proc portdistcheck::distcheck_main {args} {
 
     ui_debug "Portfile modification date is [clock format $port_moddate]"
 
-    set curl_options {}
+    set curl_options [list]
     if {[tbool fetch.ignore_sslcert]} {
         lappend curl_options "--ignore-ssl-cert"
     }
 
     # Check the distfiles if it's a regular fetch phase.
-    if {"${distcheck.type}" != "none"
-        && "${fetch.type}" == "standard"} {
+    if {${distcheck.type} ne "none"
+        && ${fetch.type} eq "standard"} {
         # portfetch 1.0::checkfiles sets fetch_urls list.
-        set fetch_urls {}
+        set fetch_urls [list]
         portfetch::checkfiles fetch_urls
         set totalsize 0
 
+        global portfetch::urlmap
         # Check all the files.
         foreach {url_var distfile} $fetch_urls {
-            global portfetch::urlmap
             if {![info exists urlmap($url_var)]} {
                 ui_error [format [msgcat::mc "No defined site for tag: %s, using master_sites"] $url_var]
                 set urlmap($url_var) $master_sites
             }
-            if {${distcheck.type} == "moddate"} {
+            if {${distcheck.type} eq "moddate"} {
                 set count 0
                 foreach site $urlmap($url_var) {
                     ui_debug [format [msgcat::mc "Checking %s from %s"] $distfile $site]
                     set file_url [portfetch::assemble_url $site $distfile]
-                    if {[catch {set urlnewer [eval curl isnewer $curl_options {$file_url} $port_moddate]} error]} {
-                        ui_warn "couldn't fetch $file_url for $subport ($error)"
-                    } else {
+                    macports_try -pass_signal {
+                        set urlnewer [curl isnewer {*}$curl_options $file_url $port_moddate]
                         if {$urlnewer} {
                             ui_warn "port $subport: $file_url is newer than Portfile"
                         }
                         incr count
+                    } on error {eMessage} {
+                        ui_debug [msgcat::mc "couldn't fetch %s for %s (%s)" $file_url $subport $eMessage]
                     }
                 }
                 if {$count == 0} {
                     ui_error "no mirror had $distfile for $subport"
                 }
-            } elseif {${distcheck.type} == "filesize"} {
+            } elseif {${distcheck.type} eq "filesize"} {
                 set count 0
                 foreach site $urlmap($url_var) {
                     ui_debug [format [msgcat::mc "Checking %s from %s"] $distfile $site]
                     set file_url [portfetch::assemble_url $site $distfile]
-                    if {[catch {set urlsize [eval curl getsize $curl_options {$file_url}]} error]} {
-                        ui_warn "couldn't fetch $file_url for $subport ($error)"
-                    } else {
+                    macports_try -pass_signal {
+                        set urlsize [curl getsize {*}$curl_options $file_url]
                         incr count
                         if {$urlsize > 0} {
                             ui_info "port $subport: $distfile $urlsize bytes"
                             incr totalsize $urlsize
                             break
                         }
+                    } on error {eMessage} {
+                        ui_debug [msgcat::mc "couldn't fetch %s for %s (%s)" $file_url $subport $eMessage]
                     }
                 }
                 if {$count == 0} {
@@ -122,7 +122,7 @@ proc portdistcheck::distcheck_main {args} {
             }
         }
 
-        if {${distcheck.type} == "filesize" && $totalsize > 0} {
+        if {${distcheck.type} eq "filesize" && $totalsize > 0} {
             if {$totalsize < 1024} {
                 set size $totalsize
                 set humansize "${size}"
